@@ -344,6 +344,7 @@ class APIAnalysisConfig:
         :param kwargs:
             - analysis_id: str
             - analysis_version_id: str
+            - subject_id: str
             - search_text: str
             - tag: str
             - min_created_on: Datetime
@@ -367,6 +368,8 @@ class APIAnalysisConfig:
                 request_fragments.append(AnalysisConfigListRequest(analysis_id=kwargs[key]))
             if key == 'analysis_version_id':
                 request_fragments.append(AnalysisConfigListRequest(analysis_version_id=kwargs[key]))
+            if key == 'subject_id':
+                request_fragments.append(AnalysisConfigListRequest(subject_id=kwargs[key]))
             if key == 'search_text':
                 request_fragments.append(AnalysisConfigListRequest(search_text=kwargs[key]))
             if key == 'tag':
